==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_SocketBase.h <==
//----------------------------------------------------------------------------
// wxSocketBase
// extracted from socket.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_SOCKETBASE_H__
#define __CLASS_WX_SOCKETBASE_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxSocketBase
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_SocketBase);

//----------------------------------------------------------------------------
// Object declaration for wxSocketBase
//----------------------------------------------------------------------------
class Object_wx_SocketBase : public Object_wx_Object {
public:
	Gura_DeclareObjectAccessor(wx_SocketBase)
public:
	inline Object_wx_SocketBase(wxSocketBase *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(Gura_UserClass(wx_SocketBase), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_SocketBase(Class *pClass, wxSocketBase *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_SocketBase();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxSocketBase *GetEntity() {
		return dynamic_cast<wxSocketBase *>(_pEntity);
	}
	inline wxSocketBase *ReleaseEntity() {
		wxSocketBase *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxSocketBase");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_SocketBase.h <==
//----------------------------------------------------------------------------
// wxSocketBase
// extracted from socket.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_SOCKETBASE_H__
#define __CLASS_WX_SOCKETBASE_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxSocketBase
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_SocketBase);

//----------------------------------------------------------------------------
// Object declaration for wxSocketBase
//----------------------------------------------------------------------------
class Object_wx_SocketBase : public Object_wx_Object {
public:
	Gura_DeclareObjectAccessor(wx_SocketBase)
public:
	inline Object_wx_SocketBase(wxSocketBase *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(Gura_UserClass(wx_SocketBase), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_SocketBase(Class *pClass, wxSocketBase *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_SocketBase();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxSocketBase *GetEntity() {
		return dynamic_cast<wxSocketBase *>(_pEntity);
	}
	inline wxSocketBase *ReleaseEntity() {
		wxSocketBase *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxSocketBase");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
